@@ -1,8 +1,8 @@
-#!/usr/bin/perl -w
+#!/usr/bin/perl
 ###############################################################################
 #    Copyright (C) 2002-2204 by Eric Gerbier
 #    Bug reports to: gerbier@users.sourceforge.net
-#    $Id: afickonfig.pl 956 2006-09-26 11:40:15Z gerbier $
+#    $Id: afickonfig.pl 1179 2008-10-15 20:18:00Z gerbier $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -23,60 +23,58 @@
 use strict;
 use warnings;
 use Pod::Usage;
+use English qw(-no_match_vars);
 
 # debuggging
-use diagnostics;
-
+#use diagnostics;
 # use Data::Dumper;
-#use Carp qw(cluck);	# debugging
 
 use Getopt::Long;    # option analysis
 
 use File::Basename;  # for path
-my $dirname = dirname($0);
+my $dirname = dirname($PROGRAM_NAME);
 require $dirname . '/afick-common.pl';
 
 ###############################################################################
 #                     global variables
 ###############################################################################
 
-my $Version = '0.5-1';
+my $Version = '0.8';
+## no critic (ProhibitPackageVars)
 use vars qw( $Verbose);
+## use critic
+
+my $EMPTY = q{};
 
 #######################################################
-# debug(message, level)
-#sub debug($;$) {
-#	my $msg = shift(@_);
-#	print "DEBUG: $msg" if ($Verbose);
-#	return;
-#}
-########################################################
-#sub warning($) {
-#	my $msg = shift(@_);
-#	warn "WARNING: $msg";
-#	return;
-#}
+# now use debug and warning sub from afick-common
+#sub debug($;$)
+#sub warning($)
 #############################################################
 # wrapper for afick commands
-sub wrapper ($$) {
-	my $configfile = shift(@_);
-	my $option     = shift(@_);
-	system("afick.pl -c $configfile $option");
+sub wrapper ($@) {
+	my $configfile = shift @_;
+	my @options    = @_;
+
+	# to use same afick as afick-common and afickonfig
+	system $dirname . '/afick.pl', '-c', $configfile, @options;
 	return;
 }
 #############################################################
 # build config line according type
 sub buildligne($$$$) {
-	my $title   = shift(@_);    # type of ligne
-	my $changes = shift(@_);    # ref to hash, containing changes
-	my $onlydir = shift(@_);    # ref to hash, for selection
-	my $key     = shift(@_);    # parameter value
+	my $title   = shift @_;    # type of ligne
+	my $changes = shift @_;    # ref to hash, containing changes
+	my $onlydir = shift @_;    # ref to hash, for selection
+	my $key     = shift @_;    # parameter value
 
+	## no critic (RequireInterpolationOfMetachars)
 	my %h_format = (
 		macro     => '@@define %s %s',
 		alias     => '%s = %s',
-		directive => '%s := %s'
+		directive => '%s := %s',
 	);
+	## use critic
 
 	if ( $title eq 'rule' ) {
 
@@ -97,34 +95,34 @@ sub buildligne($$$$) {
 		return $newligne;
 	}
 	else {
-		return sprintf( $h_format{$title}, $key, $changes->{$key} );
+		return sprintf $h_format{$title}, $key, $changes->{$key};
 	}
 }
 #############################################################
 # generic sub to apply changes on a parameter type
 sub change($$$$$) {
-	my $title        = shift(@_);    # parameter name
-	my $changes      = shift(@_);    # ref to hash, containing changes
-	my $onlydir      = shift(@_);    # ref to hash, for selection
-	my $test_pattern = shift(@_);    # ref to sub to detect adequate pattern
-	my $config       = shift(@_);    # array of config file lines
+	my $title        = shift @_;    # parameter name
+	my $changes      = shift @_;    # ref to hash, containing changes
+	my $onlydir      = shift @_;    # ref to hash, for selection
+	my $test_pattern = shift @_;    # ref to sub to detect adequate pattern
+	my $config       = shift @_;    # array of config file lines
 
 	my $nb_changes = 0;
-	foreach my $key ( keys %$changes ) {
+	foreach my $key ( keys %{$changes} ) {
 
 		debug("$title : $key");
 		my $found          = 0;
 		my $nb_changes_key = 0;
 		my $i              = 0;
 		my $newligne       = buildligne( $title, $changes, $onlydir, $key );
-		foreach my $ligne (@$config) {
+		foreach my $ligne ( @{$config} ) {
 
 			my @ret;
-			if ( @ret = &$test_pattern($ligne) ) {
+			if ( @ret = &{$test_pattern}($ligne) ) {
 
 				# found pattern
 				#print Dumper(@ret);
-				my $key_lu = shift(@ret);
+				my $key_lu = shift @ret;
 				if ( $key_lu eq $key ) {
 
 					# found same key
@@ -132,7 +130,7 @@ sub change($$$$$) {
 						print "no changes for $title $key\n";
 					}
 					elsif ( ( defined $changes->{$key} )
-						and ( $changes->{$key} eq '' ) )
+						and ( $changes->{$key} eq $EMPTY ) )
 					{
 						print "delete $title $key\n";
 						$ligne = '# ' . $ligne;
@@ -150,12 +148,14 @@ sub change($$$$$) {
 			$i++;
 		}    # foreach config
 		if ( !$found ) {
-			if ( ( defined $changes->{$key} ) and ( $changes->{$key} eq '' ) ) {
+			if (    ( defined $changes->{$key} )
+				and ( $changes->{$key} eq $EMPTY ) )
+			{
 				warning("can not delete $title $key : not found");
 			}
 			else {
 				print "add $title line $newligne\n";
-				push( @$config, $newligne );
+				push @{$config}, $newligne;
 				$nb_changes_key++;
 			}
 		}
@@ -169,13 +169,14 @@ sub change($$$$$) {
 }
 #############################################################
 # apply changes
+## no critic (ProhibitManyArgs)
 sub change_config($$$$$$) {
-	my $configfile = shift(@_);    # config file name
-	my $directives = shift(@_);    # ref to hash containing directives changes
-	my $macros     = shift(@_);    # ref to hash containing macro changes
-	my $alias      = shift(@_);    # ref to hash containing alias changes
-	my $rule       = shift(@_);    # ref to hash containing rules changes
-	my $onlydir    = shift(@_);    # ref to hash for equal selections
+	my $configfile = shift @_;    # config file name
+	my $directives = shift @_;    # ref to hash containing directives changes
+	my $macros     = shift @_;    # ref to hash containing macro changes
+	my $alias      = shift @_;    # ref to hash containing alias changes
+	my $rule       = shift @_;    # ref to hash containing rules changes
+	my $onlydir    = shift @_;    # ref to hash for equal selections
 
 	my @config;
 	read_config( $configfile, \@config ) or die get_error() . "\n";
@@ -196,7 +197,10 @@ sub change_config($$$$$$) {
 	my $nb_changes_rules =
 	  change( 'rule', $rule, $onlydir, \&is_anysel, \@config );
 
-	my $nb_changes = $nb_changes_dir + $nb_changes_macros + $nb_changes_alias +
+	my $nb_changes =
+	  $nb_changes_dir +
+	  $nb_changes_macros +
+	  $nb_changes_alias +
 	  $nb_changes_rules;
 
 	if ($nb_changes) {
@@ -209,10 +213,11 @@ sub change_config($$$$$$) {
 	}
 	return $nb_changes;
 }
+## use critic
 #############################################################
 # just display program version
 sub version($) {
-	my $version = shift(@_);
+	my $version = shift @_;
 	print
 "afickonfig : another file integrity checker configurator\nversion $version\n";
 	return;
@@ -220,9 +225,9 @@ sub version($) {
 #############################################################
 # a generic sub to add a new valid directive
 sub convert2dir($$$) {
-	my $rdir = shift(@_);    # hash table of new directives
-	my $key  = shift(@_);    # directive key
-	my $val  = shift(@_);    # directive value
+	my $rdir = shift @_;    # hash table of new directives
+	my $key  = shift @_;    # directive key
+	my $val  = shift @_;    # directive value
 
 	if ( defined $val ) {
 		if ( !defined check_directive( $key, $val, 1 ) ) {
@@ -238,10 +243,10 @@ sub convert2dir($$$) {
 #############################################################
 # add content of an environment variable
 sub add_env($$$$) {
-	my $name      = shift(@_);    # env var name
-	my $rscan     = shift(@_);    # old rules hash
-	my $rnewrules = shift(@_);    # new rules hash
-	my $ralias    = shift(@_);    # ref to alias hash
+	my $name      = shift @_;    # env var name
+	my $rscan     = shift @_;    # old rules hash
+	my $rnewrules = shift @_;    # new rules hash
+	my $ralias    = shift @_;    # ref to alias hash
 
 	my $val = $ENV{$name};
 	if ($val) {
@@ -249,12 +254,12 @@ sub add_env($$$$) {
 		my $path_sep;
 		my $microsoft = is_microsoft();
 		if ($microsoft) {
-			$path_sep = ';';
+			$path_sep = q{;};
 		}
 		else {
-			$path_sep = ':';
+			$path_sep = q{:};
 		}
-		my @tab = split( /$path_sep/, $val );
+		my @tab = split /$path_sep/, $val;
 		foreach my $elem (@tab) {
 
 			# relative or absolute path ?
@@ -264,10 +269,10 @@ sub add_env($$$$) {
 				my $elembis = reg_name($elem);
 
 				# remove trailing slash
-				$elembis =~ s?/$??;
+				$elembis =~ s{/$}{};
 
 				# absolute path
-				my $test = rech_parent( $elembis, $rscan ) || '';
+				my $test = rech_parent( $elembis, $rscan ) || $EMPTY;
 
 				debug("(add_env) $elem ($elembis) parent $test");
 				if ($test) {
@@ -313,102 +318,30 @@ sub add_env($$$$) {
 #############################################################
 # read a file and convert content to csv, delimited by ':'
 sub convert_file($) {
-	my $name = shift(@_);
+	my $name = shift @_;
 
-	my $list = '';
+	my $list = $EMPTY;
 	if ( -r $name ) {
 		my $fh;
-		open( $fh, '<', $name );
-		my @tab = <$fh>;
-		close($fh);
-		chomp(@tab);
-		$list = join( ':', @tab );
+		if ( open $fh, '<', $name ) {
+			my @tab = <$fh>;
+			close $fh or warning("can not close $name : $ERRNO");
+			chomp @tab;
+			$list = join q{:}, @tab;
+		}
+		else {
+			warning("can not open $name : $ERRNO");
+		}
 	}
 	return $list;
 }
-#######################################################
-# usage
-# print some help
-sub usage($) {
-	my $version = shift(@_);
-	print <<"EOHELP";
-
-Usage: $0 [afickonfig option] [afick options] [alias] [macros] [rules] [directives]
-
-afickonfig options (control afickonfig)  :
- -c|--config_file file        configname of config file to use
- -C|--check_config            only check config file and exit
- -G|--clean_config            check and clean configuration, then exit
- -h|--help                    show this help page
- --print_config               display internals variables after arguments and config file parsing
- 				(for debugging purposes)
- -V|--version                 show afickonfig version
- -v|--verbose		     for debugging
- --addpath		     add PATH directories to rules
- --addlib		     add libraries directories to rules (linux)
-
-afick options (change afick's options) :
-
- -a|--ignore_case             helpful on windows plateforms, dangerous on unix ones
- 				reverse : --noignore_case
- -d|--debug level	      set a level of debugging messages, from 0 (none) to 3 (full)
- -D| --database file          force the database name
- -f|--full_newdel             report full information for new or deleted directories
-			       reverse : --nofull_newdel
- -m|--missing_files           warn about files declared in config files
-                               which do not exists,
-			       reverse : --nomissing_files
- -o|--allow_overload          allow rule overload : the last rule wins
-                               reverse: --noallow_overload
- -r|--running_files           warn about "running" files : modified since program begin
-                               reverse: --norunning_files
- -s|--dead_symlinks           warn about dead symlinks
-                               reverse: --nodead_symlinks
- -t|--timing		      Print timing statistics
-				reverse : --notiming
- -x|--exclude_suffix ext1 ext2        list of file/directories suffixes to ignore
- -X|--exclude_prefix pre1 pre2        list of file/directories prefix to ignore
- -R|--exclude_re pat1 pat2        list of file/directories patterns (regular expressions) to ignore
- -y|--history file	      history file of all runs with summary
- -A|--archive directory	      directory where archive files are stored
- -S|--max_checksum_size	size  maximum cheksum size (bytes) : for bigger file, just compute checksum on begin of file
- 				( 0 means no limit)
- -Y|--follow_symlinks            checksum on links target file
-                               reverse: --nofollow_symlinks
-
-
-the following options are to be set in configuration file format :
-[macros] : '\@\@define macro value'
-[alias]  : 'newrule = attributes'
-[rules]  : 'file alias'
-[directives] : 'directive := value'
-
-Disclaimer:
-This script is intended to provide a means for
-detecting changes made to files, via a regular
-comparison of MD5 hashes to an established baseline.
-
-Copyright (c) 2002 Eric Gerbier <gerbier\@users.sourceforge.net>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-EOHELP
-	return;
-}
 #############################################################
 #                          main
 #############################################################
 
 my $default_config_file = get_default_config();
 
-$| = 1;
+$OUTPUT_AUTOFLUSH = 1;
 
 # variables for parameter analysis
 my $configfile;    # config file name
@@ -426,13 +359,14 @@ my (
 	$running,            $warn_dead_symlinks, $follow_symlinks,
 	$allow_overload,     $sufx_list,          $prefx_list,
 	$re_list,            $timing,             $database,
-	$max_checksum_size,  $output_format,      $addpath,
-	$addlib
+	$max_checksum_size,  $addpath,		$addlib,
+	#$output_format,
+	$report_syslog,
 );
 
 Getopt::Long::Configure('no_ignore_case');
-unless (
-	GetOptions(
+if (
+	!GetOptions(
 
 		# afickonfig options
 		'config_file|c=s' => \$configfile,
@@ -463,22 +397,20 @@ unless (
 		'timing|t!'             => \$timing,
 		'debug|d=i'             => \$debug_level,
 		'max_checksum_size|S=i' => \$max_checksum_size,
+		'report_syslog!'        => \$report_syslog,
 
 		#		'output_format|o=s'  => \$output_format,
 
 	)
   )
 {
-	usage($Version);
-	die "abort : incorrect option\n";
+	pod2usage('incorrect option');
 }
 
 if ($opt_help) {
 
 	# -h : help
-	#	pod2usage(1);
-	usage($Version);
-	exit;
+	pod2usage(1);
 }
 elsif ($opt_version) {
 
@@ -496,9 +428,9 @@ elsif ( -e $default_config_file ) {
 	$configfile = $default_config_file;
 }
 else {
-	usage($Version);
-	die
-"abort : missing configfile name (-c flag) and default config file $default_config_file\n";
+	pod2usage(
+"missing configfile name (-c flag) and default config file $default_config_file"
+	);
 }
 
 # some more controls
@@ -541,7 +473,9 @@ convert2dir( \%newdirectives, 'exclude_prefix',     $prefx_list );
 convert2dir( \%newdirectives, 'exclude_re',         $re_list );
 convert2dir( \%newdirectives, 'timing',             $timing );
 convert2dir( \%newdirectives, 'max_checksum_size',  $max_checksum_size );
+convert2dir( \%newdirectives, 'report_syslog',      $report_syslog );
 
+# not yet coded
 #convert2dir( \%newdirectives, 'output_format', $output_format);
 
 # get old config from, to be able to check new aliases/rules
@@ -597,11 +531,12 @@ foreach my $elem (@ARGV) {
 	remove_trailing_spaces( \$elem );
 
 	my @ret = ();
+	## no critic (ProhibitCascadingIfElse)
 	if ( @ret = is_macro($elem) ) {
 
 		# macros
-		my $key = shift(@ret);
-		my $val = shift(@ret);
+		my $key = shift @ret;
+		my $val = shift @ret;
 
 		if ( !defined check_macro( $key, $val, 1 ) ) {
 			warning( "skip macro $elem : " . get_error() );
@@ -614,8 +549,8 @@ foreach my $elem (@ARGV) {
 
 		# directives
 		# another way to set directives
-		my $key = shift(@ret);
-		my $val = shift(@ret);
+		my $key = shift @ret;
+		my $val = shift @ret;
 
 		if ( !defined check_directive( $key, $val, 1 ) ) {
 			warning( "skip directive $elem : " . get_error() );
@@ -628,8 +563,8 @@ foreach my $elem (@ARGV) {
 	elsif ( @ret = is_alias($elem) ) {
 
 		# alias
-		my $key = shift(@ret);
-		my $val = shift(@ret);
+		my $key = shift @ret;
+		my $val = shift @ret;
 
 		# we do not try to resolv aliases, because it can depends
 		# on config file definitions
@@ -647,7 +582,7 @@ foreach my $elem (@ARGV) {
 	elsif ( @ret = is_negsel($elem) ) {
 
 		# negative option
-		my $key = shift(@ret);
+		my $key = shift @ret;
 		if ( !is_anyfile($key) ) {
 			warning( "skip rule $elem : " . get_error() );
 		}
@@ -658,8 +593,8 @@ foreach my $elem (@ARGV) {
 	elsif ( @ret = is_equalsel($elem) ) {
 
 		# only dir option
-		my $name = shift(@ret);
-		my $attribute = shift(@ret) || '';
+		my $name = shift @ret;
+		my $attribute = shift @ret || $EMPTY;
 
 		# do not check resolv globbing
 		# just check attribute syntax
@@ -675,8 +610,8 @@ foreach my $elem (@ARGV) {
 	elsif ( @ret = is_sel($elem) ) {
 
 		# classic selection
-		my $name = shift(@ret);
-		my $attribute = shift(@ret) || '';
+		my $name = shift @ret;
+		my $attribute = shift @ret || $EMPTY;
 
 		# do not check resolv globbing
 		# just check attribute syntax
@@ -691,6 +626,7 @@ foreach my $elem (@ARGV) {
 	else {
 		warning("unknown element $elem (ignored)");
 	}
+	## use critic
 }
 
 my $return_value = change_config(
@@ -699,14 +635,13 @@ my $return_value = change_config(
 );
 
 # control
-wrapper( $configfile, '--check_config --debug 0' );
+wrapper( $configfile, '--check_config', '--debug', 0 );
 
 exit $return_value;
 ## no critic (UnreachableCode);
 
 __END__
 
-
 =head1 NAME
 
 afickonfig - a tool to manage Afick's config files
@@ -730,62 +665,53 @@ afick use posix syntax, which allow many possibilities :
 =over 4
 
 =item *
-
 long (--) options
 
 =item *
-
 short (-) options
 
 =item *
-
 negative (--no) options
 
 =back
 
+=head1 REQUIRED ARGUMENTS
+
 =head1 OPTIONS
 
 options are used to control afickconfig
 
 =over 4
 
-=item *
---config_file|-c configfile
+=item B<--config_file|-c configfile>
 
 read the configuration in config file named "configfile".
 
-=item *
---check_config|-C
+=item B<--check_config|-C>
 
 only check config file syntax and exit with the number of errors
 
-=item *
---clean_config|-G
+=item B<--clean_config|-G>
 
 check config file syntax, clean bad line, and exit with the number of errors
 
-=item *
---help|-?
+=item B<--help|-?>
 
 Output summary help information and exit.
 
-=item *
---man
+=item B<--man>
 
 Output full help information and exit.
 
-=item *
---print_config
+=item B<--print_config>
 
 display internals variables after arguments and config file parsing (for debugging purposes)
 
-=item *
---version|-V
+=item B<--version|-V>
 
 Output version information and exit.
 
-=item *
---verbose|-v
+=item B<--verbose|-v>
 
 add debugging messages
 
@@ -797,84 +723,68 @@ actions are used to change afick's configuration
 
 =over 4
 
-=item *
---allow_overload,(--noallow_overload)
+=item B<--allow_overload,(--noallow_overload)>
 
 if set, allow rule overload (the last rule wins), else put a warning and keep the first rule.
 
-=item *
---archive|-A directory
+=item B<--archive|-A directory>
 
 write reports to "directory".
 
-=item *
---database|-D name
+=item B<--database|-D name>
 
-use the database named "name".
+select the database named "name".
 
-=item *
---debug|-d level
+=item B<--debug|-d level>
 
 set a level of debugging messages, from 0 (none) to 3 (full)
 
-=item *
---full_newdel|-f,(--nofull_newdel)
+=item B<--full_newdel|-f,(--nofull_newdel)>
 
 (do not) report full information on new and deleted directories.
 
-=item *
---history|-y historyfile
+=item B<--history|-y historyfile>
 
 write session status to history file
 
-=item *
---ignore_case|-a
+=item B<--ignore_case|-a>
 
 ignore case for file names. Can be helpful on Windows platforms, but is dangerous on Unix ones.
 
-=item *
---missing_files|-m,(--nomissing_files)
+=item B<--missing_files|-m,(--nomissing_files)>
 
 (do not) warn about files declared in config files which does not exists.
 
-=item *
---max_checksum_size|-S size
+=item B<--max_checksum_size|-S size>
 
 fix a maximum size (bytes) for checksum. on bigger files, compute checksum only on first 'size' bytes.
 (0 means no limit)
 
-=item *
---dead_symlinks|-s,(--nodead_symlinks)
+=item B<--dead_symlinks|-s,(--nodead_symlinks)>
 
 (do not) warn about dead symlinks.
 
-=item *
---follow_symlinks,(--nofollow_symlinks)
+=item B<--follow_symlinks,(--nofollow_symlinks)>
 
 if set, do checksum on target file, else do checksum on target file name.
 
-=item *
---running_files|-r,(--norunning_files)
+=item B<--running_files|-r,(--norunning_files)>
 
 (do not) warn about "running" files : modified since program begin.
 
-=item *
---timing|-t,(--notiming)
+=item B<--timing|-t,(--notiming)>
 
 (do not) Print timing statistics.
 
-=item *
---exclude_suffix|-x "ext1 ext2 ... extn"
+=item B<--exclude_suffix|-x "ext1 ext2 ... extn">
 
 list of suffixes (files/directories ending in .ext1 or .ext2 ...) to ignore.
 
-=item *
---exclude_prefix|-X "pre1 pre2 ... pren"
+=item B<--exclude_prefix|-X "pre1 pre2 ... pren">
 
 list of prefix (files/directories beginning with pre1 or pre2 ...) to ignore.
 
-=item *
---exclude_re|-R "pat1 pat2 ... patn"
+=item B<--exclude_re|-R "pat1 pat2 ... patn">
 
 list of patterns (regular expressions) to ignore files or directories
 
@@ -900,13 +810,11 @@ you can also use
 
 =over 4
 
-=item *
---addpath
+=item --addpath
 
 add PATH directories to rules
 
-=item *
---addlib
+=item --addlib
 
 add libraries directories to rules (linux)
 
@@ -925,24 +833,21 @@ afickonfig may
 
 =over 4
 
-=item *
-change a config
+=item change a config
 
 if it can find an old config
 
-=item *
-add a config
+=item add a config
 
 if it does not find a previous value
 
-=item *
-remove a config
+=item remove a config
 
 you just have to specify a parameter without any value. the old line is commented
 
 =back
 
-=head1 EXAMPLES
+=head1 USAGE
 
 To use this program, you must just run it with same afick command line options :
 
@@ -960,10 +865,6 @@ remove lines
 
 C<afickonfig -c afick.conf 'debug:=' '@@define BATCH' 'newrule=' '/tmp'>
 
-=head1 RETURN VALUES
-
-The exit status is the number of real changes
-
 =head1 NOTES
 
 this program only use perl and its standard modules.
@@ -972,11 +873,8 @@ this program only use perl and its standard modules.
 
 =for html
 <a href="afick.conf.5.html">afick.conf(5)</a> for the configuration file syntax
-<br>
 <a href="afick-tk.1.html">afick-tk(1)</a> for the graphical interface
-<br>
 <a href="afick.1.html">afick(1)</a> for the command-line interface
-<br>
 <a href="afick_archive.1.html">afick_archive(1)</a> for a tool to manage archive's reports
 
 =for man
@@ -988,9 +886,33 @@ this program only use perl and its standard modules.
 .PP
 \fIafick_archive\fR\|(1) for a tool to manage archive's reports
 
-=head1 COPYRIGHT
+=head1 DIAGNOSTICS
 
-Copyright (c) 2002,2003,2004 Eric Gerbier
+all warnings go to stderr
+
+=head1 EXIT STATUS
+
+The exit status is the number of real changes
+
+=head1 CONFIGURATION
+
+no specific configuration file
+
+=head1 DEPENDENCIES
+
+perl
+
+=head1 INCOMPATIBILITIES
+
+(none)
+
+=head1 BUGS AND LIMITATIONS
+
+(none known)
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2002 Eric Gerbier
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
@@ -998,7 +920,7 @@ under the terms of the GNU General Public License as published by the Free
 Software Foundation; either version 2 of the License, or (at your option)
 any later version.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
 Eric Gerbier
 
